@@ -1,7 +1,5 @@
-use v5.14;
 package RosettaCode;
-
-our $VERSION = '0.0.5';
+our $VERSION = '0.0.6';
 
 use utf8;
 use MediaWiki::Bot;
@@ -98,7 +96,12 @@ sub parse_task_page {
     my ($self, $info, $content) = @_;
     Log "Parse Task '$info->{name}'";
     $content =~ s/\r//g;
-    $content =~ s/\n?\z/\n/;
+    $content =~ s/\n?\z/\n/ if length $content;
+    if ($content =~ /^#REDIRECT \[\[/) {
+        $content =~ s/\n.*//s;
+        Log "Skipping redirect: $content";
+        return;
+    }
     my ($text, $meta) = $self->parse_description(\$content)
         or $self->parse_fail($info->{name}, $content);
     my $path = $info->{path};
@@ -172,7 +175,7 @@ sub parse_next_lang_section {
     Log "Parse language section: '$lang'";
     my $original = $text;
     my @sections;
-    while ($text =~ s/<lang(?: [^>]+)?>(.*?)<\/lang>//s) {
+    while ($text =~ s/<lang(?: [^>]+)?>(.*?)<\/lang *>//si) {
         my $section = $1;
         $section =~ s/\A\s*\n//;
         $section =~ s/ *$//mg;
@@ -329,49 +332,3 @@ sub parse_fail {
 }
 
 1;
-
-=encoding utf8
-
-=head1 NAME
-
-RosettaCode - An Application to interface with http://rosettacode.org
-
-=head1 SYNOPSIS
-
-From the command line:
-
-    > rosettacode help
-    > git clone git://github.com/acmeism/RosettaCodeData.git
-    > cd RosettaCodeData
-    > rosettacode sync .
-
-=head1 DESCRIPTION
-
-RosettaCode.org is a fantastic wiki that contains ~ 650 programming tasks,
-each implemented in up to ~ 500 programming languages.
-
-This tool aims to make it easier for programmers to obtain and try the various
-code samples.
-
-At this point, the main function is to extract the code examples and put them
-into a git repository on GitHub. You probably don't need to use this tool
-yourself. You can just get the repository here:
-
-    git clone git://github.com/acmeism/RosettaCodeData.git
-
-This tool will just update all the files in that repository.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (c) 2013. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
